@@ -2,16 +2,12 @@
 package Data::Localize::Auto;
 use Any::Moose;
 
-with 'Data::Localize::Localizer';
+extends 'Data::Localize::Localizer';
 
 __PACKAGE__->meta->make_immutable;
 
 no Any::Moose;
 
-sub register {}
-
-sub get_lexicon {}
-
 sub localize_for {
     my ($self, %args) = @_;
     my ($id, $args) = @args{ qw(id args) };
@@ -21,7 +17,7 @@ sub localize_for {
         print STDERR "[Data::Localize::Auto]: localize_for - $id -> ",
             defined($value) ? $value : '(null)', "\n";
     }
-    return $self->format_string($value, @$args) if $value;
+    return $self->format_string('auto', $value, @$args) if $value;
     return ();
 }
 
